import Database from 'better-sqlite3';
import {RSSParser} from 'src/parsers/rss';
import { v4 as uuidv4 } from 'uuid';

const DB = 'feeds.db';
export const writer = new Database(DB, {
  verbose: console.log
});


writer.prepare('drop table if exists feed_items').run();
writer.prepare('drop table feedlist').run();

writer.prepare(`
               create table feedlist (
                 id text unique,
                 title text,
                 link text unique
               )
               `).run();



writer.prepare(`
               create table feed_items (
                 id text unique,
                 feed_id text,
                 guid text unique,
                 title text,
                 link text,
                 pub_date number,
                 content text,
                 read_at number default 0
               )
               `).run();


const feeds = [
  {
    id: uuidv4(),
    title: 'Scripting',
    link: 'http://scripting.com/rss.xml',
  },
  {
    id: uuidv4(),
    title: 'Hacker News Front Page',
    link: 'https://hnrss.org/frontpage'
  },
  {
    id: uuidv4(),
    title: 'Xangelo.ca',
    link: 'https://xangelo.ca/posts/index.xml'
  }
];

writer.prepare('insert into feedlist (id, title, link) values (?,?,?), (?, ?, ?), (?,?,?)').run(
  feeds[0].id, feeds[0].title, feeds[0].link,
  feeds[1].id, feeds[1].title, feeds[1].link,
  feeds[2].id, feeds[2].title, feeds[2].link
);

const insert = writer.prepare(`insert into feed_items (id, feed_id, guid, title, link, pub_date, content) values (?, ?, ?, ?, ?, ?, ?)`);
const rss = new RSSParser();
feeds.forEach(async feed => {
  const data = await rss.parse(feed.link);
  data.items.forEach(item => {
    const id = uuidv4();
    insert.run(id, feed.id, item.guid, item.title, item.link, item.pubDate, item.content);
  });
});
