import { query } from './lib/db';
import { v4 as uuidv4 } from 'uuid';
import { RSSParser } from './parsers/rss';

const rss = new RSSParser();

export async function ingestSingle(feed_id: string) {
  const feed = query.getFeedInfo.get(feed_id);
  console.log(`Ingesting ${feed.title} @ ${feed.link}`);

  const data = await rss.parse(feed.link);

  const insertedData = data.items.map(item => {
    const id = uuidv4();
    query.addFeedItem.run(id, feed.id, item.guid, item.title, item.link, item.pubDate, item.content);
    return id;
  });

  return data;
}

export async function ingest() {
  // get a list of feeds!
  const feeds = query.getFeedList.all();

  feeds.forEach(async feed => {
    console.log(`Ingesting ${feed.title} @ ${feed.link}`);
    try {
      const data = await rss.parse(feed.link);

      const insertedData = data.items.map(item => {
        const id = uuidv4();
        try {
          query.addFeedItem.run(id, feed.id, item.guid, item.title, item.link, item.pubDate, item.content);
        }
        catch(e) {
          if((e as any).code !== 'SQLITE_CONSTRAINT_UNIQUE') {
            throw e;
          }
        }
        return id;
      });
    }
    catch(e) {
      console.log(e);
    }
  });
}
