import Database from 'better-sqlite3';

const DB = 'feeds.db';

export const writer = new Database(DB, {
  verbose: console.log
});
export const reader = new Database(DB, {
  readonly: true,
  verbose: console.log
});

export const query = {
  addFeed: writer.prepare('insert into feedlist (id, title, link) values (?, ?, ?)'),
  getFeedList: reader.prepare('select * from feedlist'),
  getFeedInfo: reader.prepare('select * from feedlist where id = ?'),
  getFeedItemInfo: reader.prepare('select * from feed_items where id = ? and feed_id = ?'),
  addFeedItem: writer.prepare('insert into feed_items (id, feed_id, guid, title, link, pub_date, content) values (?, ?, ?, ?, ?, ?, ?)'),
  getFeedsFor: reader.prepare('select id, feed_id, guid, title, link, pub_date,read_at from feed_items where feed_id = ? and pub_date > ? order by pub_date desc'),
  readItem: writer.prepare('update feed_items set read_at = ? where id = ? and read_at = 0'),
  getUnreadCountForAll: reader.prepare('select count(id) as unread, feed_id from feed_items where read_at = 0 group by feed_id'),
  readAllItems: writer.prepare(`update feed_items set read_at = datetime('now') where feed_id = ?`),
  _deleteFeedItems: writer.prepare(`delete from feed_items where feed_id = ?`),
  _deleteFeed: writer.prepare(`delete from feedlist where id = ?`),
  deleteFeed: {
    run: (feed_id: string) => {
      query._deleteFeedItems.run(feed_id);
      query._deleteFeed.run(feed_id)
    }
  } 
};
