import Parser from 'rss-parser';
import {Feed, BaseParser} from './base';

function timestamp(str: string): number {
  const date = +(new Date(str));
  return Math.floor(date / 1000);
}

function reasonable(dateStr: string): string {
  const date = new Date(dateStr);
  const month = date.getMonth() < 10 ? `0${date.getMonth()}` : date.getMonth();
  const day = date.getDate() < 10 ? `0${date.getDate()}` : date.getDate();
  return `${date.getFullYear()}-${month}-${day}`;
}

export class RSSParser extends BaseParser {
  parser: Parser;
  constructor() {
    super();
    this.parser = new Parser;
  }

  async parse(url: string): Promise<Feed> {
    const feed = await this.parser.parseURL(url);

    return {
      title: feed.title || 'Unknown',
      link: feed.link || 'Unknown',
      items: feed.items.map(i => {
        const content = i.content ? i.content : i.description;
        const title = i.title ? i.title : `Posted on ${reasonable(i.pubDate || (new Date().toString()))}`;
        return {
          title: title || 'Unknown',
          link: i.link || 'Unknown',
          guid: i.guid || 'Uknown',
          content: content || 'Unknown',
          pubDate: (timestamp(i.pubDate || (new Date().toString())))
        }
      })
    }
  }
}
